<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Member
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Member
 *
 * @category   Phire
 * @package    Phire_Member
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Member extends Phire_Template
{

    /**
     * Member type
     * @var string
     */
    public $type = null;

    /**
     * Member action
     * @var string
     */
    public $action = null;

    /**
     * Member ID
     * @var int|string
     */
    public $id = null;

    /**
     * Member hash
     * @var string
     */
    public $hash = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Site member redirects
     * @var array
     */
    protected $_redirects = array();

    /**
     * Language object
     * @var Phire_Language
     */
    protected $_lang = null;

    /**
     * Constructor
     *
     * Instantiate the member object.
     *
     * @param  string $url
     * @return void
     */
    public function __construct($url)
    {

        $this->_url = $url;
        $this->_lang = new Phire_Language();
        parent::__construct();
        $this->_tmpl = Phire_Parser::getParser($this->_tmpl, $this->_url)->getContent();

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();
        $redirects = explode('|', $this->_site->member_redirects);

        $this->_redirects[0] = (isset($redirects[0])) ? $redirects[0] : '';
        $this->_redirects[1] = (isset($redirects[1])) ? $redirects[1] : '';
        $this->_redirects[2] = (isset($redirects[2])) ? $redirects[2] : '';
        $this->_redirects[3] = (isset($redirects[3])) ? $redirects[3] : '';
        $this->_redirects[4] = (isset($redirects[4])) ? $redirects[4] : '';
        $this->_redirects[5] = (isset($redirects[5])) ? $redirects[5] : '';
        $this->_redirects[6] = (isset($redirects[6])) ? $redirects[6] : '';

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

        // Get member action request and validate it.
        $urlParts = Moc10_String::setString($this->_url)->split('/');

        $this->type = (isset($urlParts[1]) ? $urlParts[1] : '');
        $this->action = (isset($urlParts[2]) ? $urlParts[2] : '');
        $this->id = (isset($urlParts[3]) ? $urlParts[3] : '');
        $this->hash = (isset($urlParts[4]) ? $urlParts[4] : '');

        $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;

        if (($this->_site->member_allow == 'No') || ($this->action == '')) {
            header('Location: ' . $base_path);
        } else if (($_SERVER['SERVER_PORT'] == 80) && ($this->_site->member_ssl_connection == 'Yes')) {
            header('Location: https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']);
        } else if (($this->action == 'login') && ($this->_site->member_enable_login == 'No')) {
            header('Location: ' . $base_path);
        } else if (($this->action == 'register') && ($this->_site->member_enable_registration == 'No')) {
            header('Location: ' . $base_path);
        }

    }

    /**
     * Process the member action
     *
     * @return void
     */
    public function process()
    {

        $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;

        switch ($this->action) {

            case 'register':
                $this->_register();
                break;

            case 'verify':
                $this->_verify();
                break;

            case 'login':
                $this->_login();
                break;

            case 'relogin':
                $sess = Moc10_Session::getInstance();
                $sess->kill();
                header('Location: ' . BASE_PATH . '/member/login');
                break;

            case 'profile':
                $this->_profile();
                break;

            case 'delete':
                $this->_delete();
                break;

            case 'unsubscribe':
                $this->_unsubscribe();
                break;

            case 'logout':
                $this->_logout();
                break;

            case 'forgot':
                $this->_forgot();
                break;

            default:
                header('Location: ' . $base_path);

        }

    }

    /**
     * Register the member
     *
     * @return void
     */
    protected function _register()
    {

        $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Registration'))->strip()->html());
        $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Registration'));
        $form = new Phire_Form_MemberRegister(BASE_PATH . '/member/register', 'post', '        ');

        if ($_POST) {

            $form->init($this->_site->member_registration, $_POST);

            if ($form->isValid()) {

                if (isset($form->fields['birth_month']) && isset($form->fields['birth_day']) && isset($form->fields['birth_year'])) {
                    $birth_date = $form->fields['birth_year'] . '-' . $form->fields['birth_month'] . '-' . $form->fields['birth_day'];
                } else {
                    $birth_date = '0000-00-00';
                }

                if ($this->_site->member_verification == 'Off') {
                    $verified = 'Yes';
                    $verify_msg = "";
                } else {
                    $verified = 'No';
                    $verify_msg = " " . $this->_lang->__('Please check your email to verify your new account.');
                }

                if ($this->_site->member_approval == 'Off') {
                    $approved = 'Yes';
                    $approval_msg = "";
                } else {
                    $approved = 'No';
                    $approval_msg = " " . $this->_lang->__('Someone will review your membership application soon for approval.');
                }

                // Determine if member password encoding is activated.
                if (!is_null($form->fields['username']) && !is_null($form->fields['password1'])) {
                    $password = ($this->_site->member_password_encoding == 'On') ? sha1($form->fields['password1']) : $form->fields['password1'];
                    $org_password = $form->fields['password1'];
                } else {
                    $password = null;
                    $org_password = null;
                }

                $fields = array('site_id' => $this->_site->site_id,
                                'username' => $form->fields['username'],
                                'password' => $password,
                                'email' => $form->fields['email'],
                                'verified' => $verified,
                                'approved' => $approved,
                                'fname' => $form->fields['fname'],
                                'lname' => $form->fields['lname'],
                                'address1' => $form->fields['address1'],
                                'address2' => $form->fields['address2'],
                                'city' => $form->fields['city'],
                                'state' => $form->fields['state'],
                                'zip' => $form->fields['zip'],
                                'country' => $form->fields['country'],
                                'organization' => $form->fields['organization'],
                                'title' => $form->fields['title'],
                                'phone' => $form->fields['phone'],
                                'birth_date' => $birth_date,
                                'gender' => $form->fields['gender'],
                                'receive_updates' => $form->fields['receive'],
                                'last_login' => '0000-00-00',
                                'last_ip' => '');

                $member = new Phire_Table_Members($fields);
                $member->save();

                if ($verified == 'No') {

                    // Build and send the verification email.
                    $rcpt = array(array('name' => $member->email,
                                        'email' => $member->email,
                                        'username' => $member->username,
                                        'password' => $org_password,
                                        'site_domain' => $this->_site->site_domain,
                                        'verify_link' => 'http://' . $this->_site->site_domain . BASE_PATH . '/member/verify/' . $member->member_id . '/' . sha1($member->email),
                                        'login_link' => 'http://' . $this->_site->site_domain . BASE_PATH . '/member/login'));

                    if (!is_null($form->fields['username']) && !is_null($form->fields['password1'])) {
                        $message = $this->_lang->__('Your member account for %1 has been created.', '[{site_domain}]') . " " . $this->_lang->__('Your credentials for the site are:') . "\n\n" . $this->_lang->__('Username:') . " [{username}]\n" . $this->_lang->__('Password:') . " [{password}]\n\n" . $this->_lang->__('In order to access the account you must verify your email address. Please click on the link below to verify your email address:') . "\n[{verify_link}]\n\n" . $this->_lang->__('Once successfully verified, you can then log in here:') . "\n[{login_link}]\n\n" . $this->_lang->__('Thank You,') . "\n\n" . $this->_lang->__('The %1 Team', '[{site_domain}]') . "\n\n";
                    } else {
                        $message = $this->_lang->__('Your member account for %1 has been created.', '[{site_domain}]') . " " . $this->_lang->__('In order to receive updates from the site, you must verify your email address. Please click on the link below to verify your email address:') . "\n[{verify_link}]\n\n" . $this->_lang->__('Thank You,') . "\n\n" . $this->_lang->__('The %1 Team', '[{site_domain}]') . "\n\n";
                    }

                    $noreply = 'noreply@' . ((stripos($this->_site->site_domain, 'www.') !== false) ? str_replace('www.', '', $this->_site->site_domain) : $this->_site->site_domain);

                    $mail = new Moc10_Mail($rcpt, null, $this->_lang->__('Member Account Created - Verification Required for %1',  $this->_site->site_domain));
                    $mail->setHeaders(array('From' => array($noreply, $noreply),
                                            'Reply-To' => array($noreply, $noreply)));

                    $mail->setText($message);
                    $mail->init();
                    $mail->send();

                }

                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Thank you for registering.') . "{$verify_msg}{$approval_msg}</p>");

                if ($this->_redirects[4] != '') {
                    header('Location: ' . $this->_redirects[4]);
                } else {
                    $this->render();
                }

            } else {
                $this->setContent('[{page_content}]', $form->render(true));
                $this->render();

            }

        } else {

            $form->init($this->_site->member_registration);
            $this->setContent('[{page_content}]', $form->render(true));
            $this->render();

        }

    }

    /**
     * Verify the member
     *
     * @throws Exception
     * @return void
     */
    protected function _verify()
    {

        if (($this->id == '') || ($this->hash == '')) {
            $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;
            header('Location: ' . $base_path);
        } else {

            $member = new Phire_Table_Members();
            $member->findById($this->id);

            if ((!isset($member->email)) || (sha1($member->email) != $this->hash)) {

                $error_msg = $this->_lang->__('There was an error regarding your data while attempting to process your member verification.');

                if ($this->_site->site_email != '') {
                    $error_msg .= $this->_lang->__('Please contact the %1website administrator%2 for assistance.', array("<a href=\"mailto:{$this->_site->site_email}\">", "</a>"));
                }

                throw new Exception($error_msg);

            } else {

                $member->verified = 'Yes';
                $member->save();

                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Verify') . ' > ' . $this->_lang->__('Success'))->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Verify') . ' &gt; ' . $this->_lang->__('Success'));
                if (($member->username != '') && ($member->password != '')) {
                    $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Thank You. You have successfully verified your email address. You may now login and contribute to %1.', "<a href=\"http://{$this->_site->site_domain}" . BASE_PATH . "/member/login\">{$this->_site->site_domain}</a>") . "</p>");
                } else {
                    $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Thank You. You have successfully verified your email address.') . "</p>");
                }

                if ($this->_redirects[0] != '') {
                    header('Location: ' . $this->_redirects[0]);
                } else {
                    $this->render();
                }

            }

        }

    }

    /**
     * Member login
     *
     * @return void
     */
    protected function _login()
    {

        $sess = Moc10_Session::getInstance();

        if (isset($sess->member_id)) {

            if (isset($sess->request)) {
                $req = $sess->request;
                unset($sess->request);
                header('Location: ' . $req);
            } else {
                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Login'))->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Login'));
                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('You are already logged into the site as %1.', "<strong>{$sess->username}</strong>") . " (" . $this->_lang->__('Not %1?', "<strong>{$sess->username}</strong>") . " <a href=\"relogin\">" . $this->_lang->__('Log back in here.') . "</a>) " . $this->_lang->__('You can log out %1here%2.', array("<a href=\"" . BASE_PATH . "/member/logout\">", "</a>")) . "</p>");
                $this->render();
            }

        } else {

            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Login'))->strip()->html());
            $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Login'));
            $form = new Phire_Form_MemberLogin(BASE_PATH . '/member/login', 'post', '        ');

            if ($_POST) {
                $form->init($_POST['username'], $_POST['password']);

                if ($form->isValid()) {

                    $member = new Phire_Table_Members();
                    $member->findBy('username', $_POST['username']);

                    $sess->member_id = $member->member_id;
                    $sess->username = $member->username;
                    $sess->email = $member->email;
                    $sess->fname = $member->fname;
                    $sess->lname = $member->lname;
                    $sess->last_login = $member->last_login;
                    $sess->last_ip = $member->last_ip;

                    $member->last_login = date('Y-m-d H:i:s');
                    $member->last_ip = $_SERVER['REMOTE_ADDR'];
                    $member->save();

                    self::__construct($this->_url);

                    $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Login'))->strip()->html());
                    $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Login'));
                    $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('You are now logged into the site as %1.', "<strong>{$sess->username}</strong>") . "(" . $this->_lang->__('Not %1?', "<strong>{$sess->username}</strong>") . " <a href=\"relogin\">" . $this->_lang->__('Log back in here.') . "</a>) " . $this->_lang->__('You can log out %1here%2.', array("<a href=\"" . BASE_PATH . "/member/logout\">", "</a>")) . "</p>");


                    if (isset($sess->request)) {
                        $req = $sess->request;
                        unset($sess->request);
                        header('Location: ' . $req);
                    } else if ($this->_redirects[1] != '') {
                        header('Location: ' . $this->_redirects[1]);
                    } else {
                        $this->render();
                    }

                } else {
                    $this->setContent('[{page_content}]', $form->render(true));
                    $this->render();
                }


            } else {
                $form->init();
                $this->setContent('[{page_content}]', $form->render(true));
                $this->render();
            }
        }

    }

    /**
     * Member profile
     *
     * @return void
     */
    protected function _profile()
    {

        $sess = Moc10_Session::getInstance();

        if (!isset($sess->member_id)) {
            $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;
            header('Location: ' . $base_path);
        } else {

            $member = new Phire_Table_Members();
            $member->findById($sess->member_id);

            if (isset($member->member_id)) {

                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Profile') . " > " . $member->username)->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Profile') . " &gt; " . $member->username);
                $form = new Phire_Form_MemberProfile(BASE_PATH . '/member/profile', 'post', '        ');

                if ($_POST) {

                    $form->init($this->_site->member_registration, $_POST, $_POST['member_id']);

                    if ($form->isValid()) {

                        if (isset($form->fields['birth_month']) && isset($form->fields['birth_day']) && isset($form->fields['birth_year'])) {
                            $birth_date = $form->fields['birth_year'] . '-' . $form->fields['birth_month'] . '-' . $form->fields['birth_day'];
                        } else {
                            $birth_date = '0000-00-00';
                        }

                        if ($form->fields['password1'] != '') {
                            // Determine if member password encoding is activated.
                            $password = ($this->_site->member_password_encoding == 'On') ? sha1($form->fields['password1']) : $form->fields['password1'];
                        } else {
                            $password = $member->password;
                        }

                        $revised_member = new Phire_Table_Members();
                        $revised_member->findById($form->fields['member_id']);

                        if (isset($sess->username)) {
                            $sess->username = $form->fields['username'];
                        }

                        $revised_member->username = $form->fields['username'];
                        $revised_member->password = $password;
                        $revised_member->fname = $form->fields['fname'];
                        $revised_member->lname = $form->fields['lname'];
                        $revised_member->address1 = $form->fields['address1'];
                        $revised_member->address2 = $form->fields['address2'];
                        $revised_member->city = $form->fields['city'];
                        $revised_member->state = $form->fields['state'];
                        $revised_member->zip = $form->fields['zip'];
                        $revised_member->country = $form->fields['country'];
                        $revised_member->organization = $form->fields['organization'];
                        $revised_member->title = $form->fields['title'];
                        $revised_member->phone = $form->fields['phone'];
                        $revised_member->birth_date = $birth_date;
                        $revised_member->gender = $form->fields['gender'];
                        $revised_member->receive_updates = $form->fields['receive'];

                        $revised_member->save();

                        $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Thank you. Your member profile has been updated.') . "</p>");

                        if ($this->_redirects[5] != '') {
                            header('Location: ' . $this->_redirects[5]);
                        } else {
                            $this->render();
                        }

                    } else {
                        $this->setContent('[{page_content}]', $form->render(true));
                        $this->render();
                    }

                } else {

                    $form->init($this->_site->member_registration, null, $member->member_id);
                    $this->setContent('[{page_content}]', $form->render(true));
                    $this->render();

                }

            } else {
                $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;
                header('Location: ' . $base_path);
            }

        }

    }

    /**
     * Delete the member (requires the member to be logged in.)
     *
     * @return void
     */
    protected function _delete()
    {

        $sess = Moc10_Session::getInstance();

        if (!isset($sess->member_id)) {
            $base_path = (is_null(BASE_PATH)) ? '/' : BASE_PATH;
            header('Location: ' . $base_path);
        } else {

            $member = new Phire_Table_Members();
            $member->findById($sess->member_id);

            if ($this->id == 'confirm') {
                $cmts = new Phire_Table_Comments();
                $cmts->execute("UPDATE " . DB_PREFIX . "comments SET member_id = 0 WHERE member_id = '" . $sess->member_id . "'");
                $sess->kill();
                self::__construct($this->_url);
                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Delete') . " > " . $member->username)->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Delete') . " &gt; " . $member->username);
                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Your member account has been successfully removed from this site.') . "</p>");
                $member->delete();

                if ($this->_redirects[6] != '') {
                    header('Location: ' . $this->_redirects[6]);
                } else {
                    $this->render();
                }

            } else {
                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Delete') . " > " . $member->username)->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Delete') . " &gt; " . $member->username);
                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Are you sure you want to delete your member account from this site? This will remove all data and information you have stored with this site or contributed to this site.') . "</p>\n        <p>" . $this->_lang->__('If so, to confirm and delete your account, %1click here%2.', array("<a href=\"" . BASE_PATH . "/member/delete/confirm\">", "</a>")) . "</p>");
                $this->render();
            }

        }

    }

    /**
     * Member unsubscribe (does not require the member to be logged in.)
     *
     * @return void
     */
    protected function _unsubscribe()
    {

        if ($this->id == '') {

            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Unsubscribe'))->strip()->html());
            $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Unsubscribe'));
            $form = new Phire_Form_MemberUnsubscribe(BASE_PATH . '/member/unsubscribe', 'post', '        ');

            if ($_POST) {
                $form->init($_POST['email']);
                if ($form->isValid()) {
                    $member = new Phire_Table_Members();
                    $member->findBy('email', $_POST['email']);
                    header('Location: ' . BASE_PATH . '/member/unsubscribe/' . $member->member_id);
                } else {
                    $this->setContent('[{page_content}]', $form->render(true));
                    $this->render();
                }
            } else {
                $form->init();
                $this->setContent('[{page_content}]', $form->render(true));
                $this->render();
            }

        } else {

            $member = new Phire_Table_Members();
            $member->findById($this->id);

            if ($this->hash == 'confirm') {
                $cmts = new Phire_Table_Comments();
                $cmts->execute("UPDATE " . DB_PREFIX . "comments SET member_id = 0 WHERE member_id = '" . $this->id . "'");
                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Unsubscribe') . " > " . $member->email)->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Unsubscribe') . " &gt; " . $member->email);
                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Your member account has been successfully unsubscribed from this site.') . "</p>");
                $member->delete();
                if ($this->_redirects[6] != '') {
                    header('Location: ' . $this->_redirects[6]);
                } else {
                    $this->render();
                }
            } else {
                $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Unsubscribe') . " > " . $member->email)->strip()->html());
                $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Unsubscribe') . " &gt; " . $member->email);
                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('Are you sure you want to unsubscribe from this site? This will remove all data and information you have stored with this site or contributed to this site.') . "</p>\n        <p>" . $this->_lang->__('If so, to confirm and delete your account, %1click here%2.', array("<a href=\"" . BASE_PATH . "/member/unsubscribe/{$this->id}/confirm\">", "</a>")) . "</p>");
                $this->render();
            }

        }

    }

    /**
     * Member logout
     *
     * @return void
     */
    protected function _logout()
    {

        $sess = Moc10_Session::getInstance();
        $sess->kill();

        self::__construct($this->_url);

        $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Member Logout'))->strip()->html());
        $this->setContent('[{page_sub_title}]', $this->_lang->__('Member Logout'));
        $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('You are now logged out. You can log back in %1here%2.', array("<a href=\"" . BASE_PATH . "/member/login\">", "</a>")) . "</p>");

        if ($this->_redirects[2] != '') {
            header('Location: ' . $this->_redirects[2]);
        } else {
            $this->render();
        }

    }

    /**
     * Password reminder
     *
     * @return void
     */
    protected function _forgot()
    {

        $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_lang->__('Forgot Password'))->strip()->html());
        $this->setContent('[{page_sub_title}]', $this->_lang->__('Forgot Password'));
        $form = new Phire_Form_MemberForgot(BASE_PATH . '/member/forgot', 'post', '        ');

        if ($_POST) {
            $form->init($_POST['email']);

            if ($form->isValid()) {

                $member = new Phire_Table_Members();
                $member->findBy('email', $_POST['email']);

                if ($this->_site->member_password_encoding == 'On') {
                    $pass = strtolower(Moc10_String::setString('')->random(8));
                    $member->password = sha1($pass);
                    $member->save();
                    $message = $this->_lang->__('Due to security measures enforced by the site admin, the password to your member account for %1 has been changed.', '[{site_domain}]') . " " . $this->_lang->__('Your new credentials for %1 are:', '[{site_domain}]') . "\n\n" . $this->_lang->__('Username:') . " [{username}]\n" . $this->_lang->__('Password:') . " [{password}]\n\n" . $this->_lang->__('You can log in at the link below and change your password or manage your account:') . "\n[{login_link}]\n\n" . $this->_lang->__('Thank You,') . "\n" . $this->_lang->__('The %1 Team.', '[{site_domain}]') . "\n";
                } else {
                    $pass = $member->password;
                    $message = $this->_lang->__('Your credentials for the site are:') . "\n\n" . $this->_lang->__('Username:') . " [{username}]\n" . $this->_lang->__('Password:') . " [{password}]\n\n" . $this->_lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $this->_lang->__('Thank You,') . "\n\n" . $this->_lang->__('The %1 Team', '[{site_domain}]') . "\n\n";
                }

                // Build and send the reminder email.
                $rcpt = array(array('name' => $member->email,
                                    'email' => $member->email,
                                    'username' => $member->username,
                                    'password' => $pass,
                                    'site_domain' => $this->_site->site_domain,
                                    'login_link' => 'http://' . $this->_site->site_domain . BASE_PATH . '/member/login'));

                $noreply = 'noreply@' . ((stripos($this->_site->site_domain, 'www.') !== false) ? str_replace('www.', '', $this->_site->site_domain) : $this->_site->site_domain);

                $mail = new Moc10_Mail($rcpt, null, $this->_lang->__('Member Account - Password Reminder for %1.', $this->_site->site_domain));
                $mail->setHeaders(array('From' => array($noreply, $noreply),
                                        'Reply-To' => array($noreply, $noreply)));

                $mail->setText($message);
                $mail->init();
                $mail->send();

                $this->setContent('[{page_content}]', "        <p>" . $this->_lang->__('A password reminder has been sent to your email. Please check your email for your credentials and then login %1here%2.', array("<a href=\"" . BASE_PATH . "/member/login\">", "</a>")) . "</p>");

                if ($this->_redirects[3] != '') {
                    header('Location: ' . $this->_redirects[3]);
                } else {
                    $this->render();
                }

            } else {
                $this->setContent('[{page_content}]', $form->render(true));
                $this->render();
            }


        } else {
            $form->init();
            $this->setContent('[{page_content}]', $form->render(true));
            $this->render();
        }

    }

}
